# WARNING: This package is synchronized with Fedora!

%define major 4
%define libname %mklibname %name %major
%define libname_devel %mklibname -d %name

%global btrfs_version 3.16.2
%global util_linux_version 2.24

Name:		snapper
Version:	0.5.6
Release:	%mkrel 16
License:	GPLv2
Group:		File tools
BuildRequires:	boost-devel
BuildRequires:	gettext
BuildRequires:	libtool
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pam-devel
BuildRequires:	pkgconfig(libxslt)
BuildRequires:	xsltproc
BuildRequires:	docbook-style-xsl
BuildRequires:	libacl-devel
BuildRequires:	btrfs-devel >= %{btrfs_version}
BuildRequires:	pkgconfig(mount) >= %{util_linux_version}
BuildRequires:	e2fsprogs-devel

Requires:	%{libname}%{?_isa} = %{version}-%{release}
Requires:	diffutils
Summary:	Tool for filesystem snapshot management
URL:		http://snapper.io

Source0:	https://ftp.suse.com/pub/projects/snapper/%{name}-%{version}.tar.bz2

# Patches from Fedora
Patch0:		%{name}-remove-ext4-info-xml.patch
Patch1:		%{name}-securelibdir.patch

# Patches from upstream
Patch100:	1453b7f147e25875d10c3e66e337093603d9e27e.patch

# Mageia
Patch200:	snapper-0.5.0-pthread.patch
Patch201:	snapper-autoconf.patch
Patch202:	snapper-missing-include.patch

%description
This package contains snapper, a tool for filesystem snapshot management.

%package -n %{libname}
Summary:	Library for filesystem snapshot management
Group:		System/Libraries
Requires:	util-linux >= %{util_linux_version}
Requires:	btrfs-progs >= %{btrfs_version}

%description -n %{libname}
This package contains the snapper shared library
for filesystem snapshot management.

%package -n %{libname_devel}
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{name} = %{version}-%{release}
Requires:	libstdc++-devel
Requires:	boost-devel
Requires:	libxml2-devel
Requires:	libmount-devel >= %{util_linux_version}
Summary:	Header files and documentation for libsnapper

%description -n %{libname_devel}
This package contains header files and documentation for developing with
snapper.

%package -n pam_%{name}
Requires:	%{name} = %version-%{release}
Requires:	pam
Summary:	PAM module for calling snapper
Group:		System/Libraries

%description -n pam_%{name}
A PAM module for calling snapper during user login and logout.

%prep
%autosetup -p1

# use libexecdir
find -type f -exec sed -i -e "s|/usr/lib/snapper|%{_libexecdir}/%{name}|g" {} ';'

%build
# NOTE: This needed for regenerating the configuration to include changes from patches
autoreconf -vfi

# NOTE: --disable-ext4 option removes support for ext4 internal snapshots since the feature
# never made it into upstream kernel
%configure --disable-silent-rules --disable-ext4 --disable-zypp
#NOTE: avoid 'unused-direct-shlib-dependency' warning in rpmlint checks
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool
%make_build

%install
%make_install
install -m644 -D data/sysconfig.snapper %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{find_lang} %{name}
rm -f %{buildroot}/%{_libdir}/*.la
rm -f %{buildroot}/%{_libdir}/security/*.la
rm -rf %{buildroot}/%{_sysconfdir}/cron.hourly
rm -rf %{buildroot}/%{_sysconfdir}/cron.daily
rm -rf %{buildroot}/%{_docdir}/%{name}/COPYING

%files -f %{name}.lang
%license COPYING
%doc AUTHORS
%{_bindir}/snapper
%{_sbindir}/mksubvolume
%{_sbindir}/snapperd
%config(noreplace) %{_sysconfdir}/logrotate.d/snapper
%{_unitdir}/%{name}-*.timer
%{_unitdir}/%{name}-*.service
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.opensuse.Snapper.conf
%{_datadir}/dbus-1/system-services/org.opensuse.Snapper.service
%{_mandir}/man8/%{name}.8*
%{_mandir}/man8/mksubvolume.8*
%{_mandir}/man8/snapperd.8*
%{_mandir}/man5/snapper-configs.5*
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/installation-helper
%{_libexecdir}/%{name}/systemd-helper

%files -n %{libname}
%license COPYING
%{_libdir}/libsnapper.so.%{major}
%{_libdir}/libsnapper.so.%{major}.*
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/configs
%dir %{_sysconfdir}/%{name}/config-templates
%config(noreplace) %{_sysconfdir}/%{name}/config-templates/default
%dir %{_sysconfdir}/%{name}/filters
%config(noreplace) %{_sysconfdir}/%{name}/filters/*.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}

%files -n %{libname_devel}
%doc examples/c/*.c
%doc examples/c++-lib/*.cc
%{_libdir}/libsnapper.so
%{_includedir}/%{name}

%files -n pam_%{name}
%{_libdir}/security/pam_snapper.so
%dir %{_prefix}/lib/pam_snapper
%{_prefix}/lib/pam_snapper/*.sh
%doc %{_mandir}/*/pam_snapper*.*



%changelog
* Wed Jun 19 2024 wally <wally> 0.5.6-16.mga10
+ Revision: 2075469
- add patch to fix missing include
- rebuild for boost 1.85.0

* Fri Jan 12 2024 wally <wally> 0.5.6-15.mga10
+ Revision: 2030596
- rebuild for boost 1.84.0

* Wed Sep 27 2023 wally <wally> 0.5.6-14.mga10
+ Revision: 1991498
- rebuild for boost 1.83.0

* Sat Dec 24 2022 wally <wally> 0.5.6-13.mga9
+ Revision: 1926531
- rebuild for boost 1.81.0

* Sun Jul 03 2022 wally <wally> 0.5.6-12.mga9
+ Revision: 1867312
- rebuild for boost 1.79.0

* Wed Mar 30 2022 umeabot <umeabot> 0.5.6-11.mga9
+ Revision: 1834277
- Mageia 9 Mass Rebuild

* Sun Dec 19 2021 wally <wally> 0.5.6-10.mga9
+ Revision: 1762656
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 0.5.6-9.mga9
+ Revision: 1744711
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 0.5.6-8.mga9
+ Revision: 1723019
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 0.5.6-7.mga8
+ Revision: 1666818
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 0.5.6-6.mga8
+ Revision: 1662060
- rebuild for boost 1.74.0

* Sat Oct 31 2020 wally <wally> 0.5.6-5.mga8
+ Revision: 1640929
- fix build with autoconf > 2.69

* Sun May 03 2020 wally <wally> 0.5.6-4.mga8
+ Revision: 1578112
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 0.5.6-3.mga8
+ Revision: 1544900
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 0.5.6-2.mga8
+ Revision: 1483433
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x

* Fri Nov 02 2018 pterjan <pterjan> 0.5.6-1.mga7
+ Revision: 1327607
- Add upstream patch to fix build on arm
- Update to 0.5.6

* Thu Oct 18 2018 wally <wally> 0.5.0-4.mga7
+ Revision: 1322006
- add patch to fix linking
- rebuild for new boost 1.68.0

* Thu Oct 04 2018 umeabot <umeabot> 0.5.0-3.mga7
+ Revision: 1317383
- Mageia 7 Mass Rebuild
- Mageia 7 Mass Rebuild

* Tue Jan 09 2018 ngompa <ngompa> 0.5.0-1.mga7
+ Revision: 1191848
- Update to 0.5.0

* Mon Jan 08 2018 wally <wally> 0.4.1-4.mga7
+ Revision: 1191619
- add patch to fix build with gcc7
- rebuild for new boost
+ tv <tv>
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 0.4.1-2.mga7
+ Revision: 1154543
- rebuild with latest boost

* Thu Mar 23 2017 ngompa <ngompa> 0.4.1-1.mga6
+ Revision: 1094584
- Update to 0.4.1
- Use proper libexec dir for helper binaries

* Sun Sep 25 2016 ngompa <ngompa> 0.3.3-1.mga6
+ Revision: 1055954
- Upgrade to 0.3.3

* Wed Feb 17 2016 umeabot <umeabot> 0.2.8-5.mga6
+ Revision: 962862
- Mageia 6 Mass Rebuild

* Sun Dec 27 2015 daviddavid <daviddavid> 0.2.8-4.mga6
+ Revision: 916100
- rebuild for new boost 1.60.0

* Wed Nov 18 2015 ngompa <ngompa> 0.2.8-3.mga6
+ Revision: 903974
- Add patch for cleanup.service to use libexecdir

* Mon Nov 16 2015 ngompa <ngompa> 0.2.8-2.mga6
+ Revision: 903484
- Import snapper into Mageia


* Sun Nov 15 2015 Neal Gompa <ngompa13{%%}gmail{*}com> - 0.2.8-2
- Port to Mageia

* Mon Nov 02 2015 Ondrej Kozina <okozina@redhat.com> - 0.2.8-1
- Update to snapper 0.2.8

* Thu Aug 27 2015 Jonathan Wakely <jwakely@redhat.com> - 0.2.6-2
- Rebuilt for Boost 1.59

* Wed Aug 19 2015 Ondrej Kozina <okozina@redhat.com> - 0.2.6-1
- Update to snapper 0.2.6

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.5-6
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 0.2.5-5
- rebuild for Boost 1.58

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.2.5-3
- Rebuilt for GCC 5 C++11 ABI change

* Sat Feb 07 2015 Ondrej Kozina <okozina@redhat.com> - 0.2.5-2
- Rebuild for boost 1.57.0

* Fri Jan 30 2015 Ondrej Kozina <okozina@redhat.com> - 0.2.5-1
- Update to snapper 0.2.5
- enable rollback support (btrfs, w/o grub2 plugin yet)

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> - 0.2.3-3
- Rebuild for boost 1.57.0

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Jul 30 2014 Ondrej Kozina <okozina@redhat.com> - 0.2.3-1
- Update to snapper 0.2.3
- patch: enable systemd timer files

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 0.1.8-2
- Rebuild for boost 1.55.0

* Wed Dec 04 2013 Ondrej Kozina <okozina@redhat.com> - 0.1.8-1
- Update to snapper 0.1.8

* Fri Nov 01 2013 Ondrej Kozina <okozina@redhat.com> - 0.1.7-1
- Update to snapper 0.1.7.
- removed --enable-xattrs (already enabled by default)
- patch: reflect recent change in libbtrfs API

* Wed Jul 31 2013 Ondrej Kozina <okozina@redhat.com> - 0.1.5-2
- Add a missing requirement on crontabs to spec file (#989115)

* Mon Jul 29 2013 Ondrej Kozina <okozina@redhat.com> - 0.1.5-1
- updated to latest upstream
- allow whitespace in ALLOW_USERS and ALLOW_GROUPS
- enable new pam module
- modified specfile to reflect recent change in %%doc macro (no more version suffix)
- patch: pam module installed in proper libdir

* Sat Jul 27 2013 Petr Machata <pmachata@redhat.com> - 0.1.3-2.20130426git35ff4ec
- rebuild for boost 1.54.0
- Boost.Thread DSO does not include -mt suffix anymore (snapper-boost-mt.patch)

* Fri Apr 26 2013 Ondrej Kozina <okozina@redhat.com> - 0.1.3-1.20130426git35ff4ec
- fixed possible security vulnerability in extended attributes handling

* Thu Apr 18 2013 Ondrej Kozina <okozina@redhat.com> - 0.1.3-1.20130418git7ca81a2
- updatet to latest upstream version
- add support to compare extended attributes ('xadiff' command)
- add support to revert modificiations in file's extended attributes
- patch: avoid useless build dependency on libattr-devel

* Mon Feb 11 2013 Ondrej Kozina <okozina@redhat.com> - 0.1.2-1.20130211git676556f
- updated to latest upstream version
- fixed wrong include: "auto_ptr.h" -> <memory>
- moved diffutils dependency to client

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.1.0-2.20121026git1aaa372
- Rebuild for Boost-1.53.0

* Fri Oct 26 2012 Ondrej Kozina <okozina@redhat.com> - 0.1.0-1.20121026git1aaa372
- removed python binding since python can use dbus interface instead
- removed btrfs-progs and LVM dependecies (#852174)
- patch: do not build zypp plugin
- patch: avoid abrt when 'diff' command is executed without arguments
- patch: do not check for btrfs-progs binary
- patch: do not allow 'create-config' command on non-thin LVM volumes (#852174)
- edit libtool script to link with: '-Wl, --as-needed'
- spec file polishing

* Wed Sep 26 2012 Ondrej Kozina <okozina@redhat.com> - 0.0.14-3.20120926git7918e5c
- add dbus interface
- patch man page to reflect unsupported ext4 snapshots

* Wed Sep 5 2012 Ondrej Kozina <okozina@redhat.com> - 0.0.14-2.20120905gitb0d0145
- Rename cron files
- Fix multiple review notes issued in (#852174)

* Mon Aug 27 2012 Ondrej Kozina <okozina@redhat.com> - 0.0.14-1
- Initial build
